@@ -461,12 +461,12 @@ class Heatmap:
 class Dash_app:
 
     @classmethod
-    def configure_app(cls, data, fig, mode='inline', port=8051, interval=5e3, qubit_number=None):
+    def configure_app(cls, data, fig, mode='inline', port=8051, interval=4e3, qubit_id=None):
         cls.fig = fig
         cls.mode = mode
         cls.interval = interval
         cls.port = port
-        cls.qubit_number = qubit_number
+        cls.qubit_number = qubit_id
 
         disabled_btn = False
         disabled_input = False
@@ -527,29 +527,29 @@ class Dash_app:
             changed_id = [p['prop_id'] for p in callback_context.triggered][0]
             if 'btn-nclicks-1' in changed_id:
 
-                file_name = ('TTS_' + 'q' + str(cls.qubit_number) + '_0' + str(datetime.now().strftime(
-                    "_%H-%M-%S")) + '.csv' if cls.qubit_number is not None else 'TTS_' + 'q' + '_0' + str(
+                file_name = ('TTS_' + 'q' + str(cls.qubit_number) + str(datetime.now().strftime(
+                    "_%H-%M-%S")) + '.csv' if cls.qubit_number is not None else 'TTS_' + 'q' + '_untitled_' + str(
                     datetime.now().strftime("_%H-%M-%S")) + '.csv')
 
                 data.get_result().to_csv(_save_path(file_name, cls.qubit_number), index=False)
             elif 'btn-nclicks-2' in changed_id:
 
-                file_name = ('TTS_'+'q'+str(cls.qubit_number)+'_0'+str(datetime.now().strftime(
-                    "_%H-%M-%S"))+'.pdf' if cls.qubit_number is not None else 'TTS_'+'q'+'_0'+str(
+                file_name = ('TTS_'+'q'+str(cls.qubit_number)+str(datetime.now().strftime(
+                    "_%H-%M-%S"))+'.pdf' if cls.qubit_number is not None else 'TTS_'+'q'+'_untitled_'+str(
                     datetime.now().strftime("_%H-%M-%S"))+'.pdf')
 
                 fig.write_image(_save_path(file_name, cls.qubit_number))
             elif 'btn-nclicks-3' in changed_id:
 
-                file_name = ('TTS_' + 'q' + str(cls.qubit_number) + '_0' + str(datetime.now().strftime(
-                    "_%H-%M-%S")) + '.html' if cls.qubit_number is not None else 'TTS_' + 'q' + '_0' + str(
+                file_name = ('TTS_' + 'q' + str(cls.qubit_number) + str(datetime.now().strftime(
+                    "_%H-%M-%S")) + '.html' if cls.qubit_number is not None else 'TTS_' + 'q' + '_untitled_' + str(
                     datetime.now().strftime("_%H-%M-%S")) + '.html')
 
                 fig.write_html(_save_path(file_name, cls.qubit_number))
             elif 'btn-nclicks-5' in changed_id:
 
-                file_name = ('TTS_' + 'q' + str(cls.qubit_number) + '_0' + str(datetime.now().strftime(
-                    "_%H-%M-%S")) + '.svg' if cls.qubit_number is not None else 'TTS_' + 'q' + '_0' + str(
+                file_name = ('TTS_' + 'q' + str(cls.qubit_number) + str(datetime.now().strftime(
+                    "_%H-%M-%S")) + '.svg' if cls.qubit_number is not None else 'TTS_' + 'q' + '_untitled_' + str(
                     datetime.now().strftime("_%H-%M-%S")) + '.svg')
 
                 fig.write_image(_save_path(file_name, cls.qubit_number))
